@@ -49,8 +49,8 @@
 #' @seealso \link[stats]{approx} for information about the function used for
 #'   linear interpolation.
 #'
-#' \link{mt_resample} for resampling trajectories using a constant time
-#' interval.
+#'   \link{mt_resample} for resampling trajectories using a constant time
+#'   interval.
 #'
 #' @examples
 #' mt_example <- mt_time_normalize(mt_example,
@@ -453,10 +453,10 @@ mt_space_normalize <- function(
 #'
 #' @seealso \link{mt_align_start} for aligning the start position of 
 #'   trajectories.
-#'   
+#'
 #'   \link{mt_align} as a general purpose function for aligning and rescaling 
 #'   trajectories.
-#'   
+#'
 #'   \link{mt_remap_symmetric} for remapping trajectories.
 #'
 #' @examples
@@ -499,14 +499,15 @@ mt_align_start_end <- function(
   
   # If no start coordinates are provided, compute them
   if(is.null(start)){
-    start <- colMeans(trajectories[,1,dimensions,drop=FALSE])
+    start <- as.vector(colMeans(trajectories[,1,dimensions,drop=FALSE]))
+    names(start) <- dimensions
     if(verbose) {
       message("No start coordinates were provided. ",
               "Aligning to: ",paste(start,collapse=","))
     }
   }
   
-  # If no start coordinates are provided, compute them
+  # If no end coordinates are provided, compute them
   if(is.null(end)){
     end <- colMeans(trajectories_last)
     if(verbose) {
@@ -515,7 +516,6 @@ mt_align_start_end <- function(
     }
   }
   
-  
   # Perform alignment
   for (j in 1:length(dimensions)) {
     
@@ -545,7 +545,7 @@ mt_align_start_end <- function(
 #'
 #' @seealso \link{mt_align_start_end}  for aligning the start and end position
 #'   of trajectories.
-#'   
+#'
 #'   \link{mt_align} as a general purpose function for aligning and rescaling 
 #'   trajectories.
 #'
@@ -584,7 +584,8 @@ mt_align_start <- function(
   
   # If no start coordinates are provided, compute them
   if(is.null(start)){
-    start <- colMeans(trajectories[,1,dimensions,drop=FALSE])
+    start <- as.vector(colMeans(trajectories[,1,dimensions,drop=FALSE]))
+    names(start) <- dimensions
     if(verbose) {
       message("No start coordinates were provided. ",
               "Aligning to: ",paste(start,collapse=","))
@@ -655,11 +656,11 @@ mt_align_start <- function(
 #'   only the resampled trajectories will be returned.
 #'
 #' @seealso \link[stats]{approx} for information about the function used for
-#' linear interpolation.
+#'   linear interpolation.
 #'
-#' \link{mt_average} for averaging trajectories across constant time intervals.
+#'   \link{mt_average} for averaging trajectories across constant time intervals.
 #'
-#' \link{mt_time_normalize} for time-normalizing trajectories.
+#'   \link{mt_time_normalize} for time-normalizing trajectories.
 #'
 #' @examples
 #' mt_example <- mt_resample(mt_example,
@@ -839,8 +840,8 @@ mt_resample <- function(data,
 #' @seealso \link{mt_derivatives} for calculating velocity and
 #'   acceleration.
 #'
-#' \link{mt_resample} for resampling trajectories using a constant time
-#' interval.
+#'   \link{mt_resample} for resampling trajectories using a constant time
+#'   interval.
 #' 
 #' @author
 #' Pascal J. Kieslich (\email{kieslich@@psychologie.uni-mannheim.de})
@@ -1021,10 +1022,10 @@ mt_average <- function(data,
 #'   data and trajectories.
 #'
 #' @seealso \link{subset} for the R base subset function for vectors, matrices,
-#' or data.frames.
+#'   or data.frames.
 #'
-#' \link{mt_reshape} for information about the subset argument in various other
-#' mousetrap functions.
+#'   \link{mt_reshape} for information about the subset argument in various other
+#'   mousetrap functions.
 #'
 #' @examples
 #' # Subset based on trial data
@@ -1093,12 +1094,12 @@ mt_subset <- function(data, subset, check="data") {
 #'   that should be used for counting the number of observations. If several
 #'   dimensions are specified, the number of complete observations are reported.
 #' @return A mousetrap data object (see \link{mt_example}).
-#'   
+#'
 #'   If a data.frame with label specified in \code{save_as} (by default 
 #'   "measures") already exists, the number of observations (called \code{nobs})
 #'   are added as additional column. If not, an additional \link{data.frame}
 #'   will be added.
-#'   
+#'
 #'   If a trajectory array was provided directly as \code{data}, only a named
 #'   character vector will be returned.
 #'
